<?php

namespace Drupal\cforge\Installer;

use Drupal\node\Entity\Node;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Choose between different Cforge flavours.
 */
class ChooseFlavour extends FormBase {

  private $installer;
  private $accountSwitcher;
  private $languageManager;

  /**
   * Constructor.
   */
  public function __construct($module_installer, $account_switcher, $language_manager) {
    $this->installer = $module_installer;
    $this->accountSwitcher = $account_switcher;
    $this->languageManager = $language_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('module_installer'),
      $container->get('account_switcher'),
      $container->get('language_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'cforge_flavour_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form_state->loadInclude('hamlets', 'module');
    $form['#title'] = t('Choose flavour');
    $options = ['upgrade' => 'Hamlets upgrade from Drupal 7'] + CFORGE_FLAVOURS;
    asort($options);
    $form['flavour'] = [
      '#title' => $this->t('Flavour', [], ['context' => 'Installation variety']),
      '#type' => 'radios',
      '#options' => $options,
      '#default_value' => 'hamlets',
      '#required' => TRUE,
      '#weight' => 4,
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => 'submit',
      '#weight' => 10,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $modules = [];
    $flavour_module = $form_state->getValue('flavour');
    if ($flavour_module == 'upgrade') {
      $modules += [
        'migrate',
        'migrate_drupal',
        'migrate_drupal_ui',
        'migrate_plus',
        'migrate_tools',
        'migrate_upgrade',
        'options'
      ];
      //avoid the setup and go to /upgrade
      $flavour_module = 'hamlets';
    }
    $modules[] = $flavour_module;

    $this->configFactory()->getEditable('cforge.settings')
      ->set('flavour', $flavour_module)
      ->save();

    // The default content module is already installed and will pick up from the
    // content directory in each module installed here
    $this->installer->install($modules);

    // Swop out the tokens in the privacy policy template and tell the cookie
    // compliance module what path it is.
    if ($node = \Drupal\node\Entity\Node::load(NID_PRIVACY_POLICY)) {
      $node->body->value = \Drupal::token()->replace( $node->body->value, [], ['sanitize' => TRUE]);
      $node->save();
      $this->configFactory()->getEditable('eu_cookie_compliance.settings')
        ->set('popup_link', '/node/'.NID_PRIVACY_POLICY)
        ->save();
    }
    else {
      $this->messenger()->addWarning('Unable to find privacy node to replace tokens');
    }

    // Assume all the default content is public
    // set imported nodes to public using the cforge flag for that purpose.
    // set node owners to 1 because AccountSwitcher doesn't work.
    foreach (Node::loadMultiple() as $node) {
      $node->setOwnerId(1);
      if ($node->bundle() == 'page') {
        cforge_node_set_anonaccess($node->id(), TRUE);
      }
    }
    $this->installer->uninstall(['hal', 'default_content']);
  }


}
